@@ -175,6 +175,12 @@ class LocalConf(object):
                 if in_section:
                     yield line
 
+    def _has_local_section(self):
+        for group in self.groups():
+            if group == ("local", "localrc"):
+                return True
+        return False
+
     def extract(self, group, conf, target):
         ini_file = IniFile(target)
         for section, name, value in self._conf(group, conf):
@@ -186,9 +192,28 @@ class LocalConf(object):
                 f.write(line)
 
     def _at_insert_point_local(self, name, func):
+        """Run function when we are at the right insertion point in file.
+
+        This lets us process an arbitrary file and insert content at
+        the correct point. It has a few different state flags that we
+        are looking for.
+
+        Does this file have a local section at all? If not, we need to
+        write one early in the file (this means we work with an empty
+        file, as well as a file that has only post-config sections.
+
+        Are we currently in a local section, if so, we need to write
+        out content to the end, because items added to local always
+        have to be added at the end.
+
+        Did we write out the work that we expected? If so, just blast
+        all lines to the end of the file.
+
+        """
         temp = tempfile.NamedTemporaryFile(mode='r')
         shutil.copyfile(self.fname, temp.name)
-        in_meta = False
+        in_local = False
+        has_local = self._has_local_section()
         done = False
         with open(self.fname, "w+") as writer:
             with open(temp.name) as reader:
@@ -198,46 +223,32 @@ class LocalConf(object):
                         continue
 
                     if re.match(re.escape("[[local|localrc]]"), line):
-                        in_meta = True
-                        writer.write(line)
-                    elif re.match("\[\[.*\|.*\]\]", line):
-                        # if we're not done yet, we
-                        if in_meta:
-                            func(writer, None)
-                            writer.write(line)
-                            done = True
-                        in_meta = False
-                        continue
-                    elif re.match("\s*%s\s*\=" % re.escape(name), line):
-                        # we found our key, pass to the writer func
-                        func(writer, line)
+                        in_local = True
+                    elif in_local and re.match(re.escape("[["), line):
+                        func(writer, None)
                         done = True
-                    else:
-                        # write out whatever we find
-                        writer.write(line)
+                        in_local = False
+                    elif not has_local and re.match(re.escape("[["), line):
+                        writer.write("[[local|localrc]]\n")
+                        func(writer, None)
+                        done = True
+                        in_local = False
+                        has_local = True
+
+                    # otherwise, just write what we found
+                    writer.write(line)
             if not done:
                 func(writer, None)
 
-    def set_local(self, name, value):
+    def set_local(self, line):
         if not os.path.exists(self.fname):
             with open(self.fname, "w+") as writer:
                 writer.write("[[local|localrc]]\n")
-                writer.write("%s=%s\n" % (name, value))
-                return
-
-        def _do_set(writer, line):
-            writer.write("%s=%s\n" % (name, value))
-        self._at_insert_point_local(name, _do_set)
-
-    def set_local_raw(self, line):
-        if not os.path.exists(self.fname):
-            with open(self.fname, "w+") as writer:
-                writer.write("[[local|localrc]]\n")
-                writer.write("%s" % line)
+                writer.write("%s\n" % line.rstrip())
                 return
 
         def _do_set(writer, no_line):
-            writer.write("%s" % line)
+            writer.write("%s\n" % line.rstrip())
         self._at_insert_point_local(line, _do_set)
 
     def _at_insert_point(self, group, conf, section, name, func):
@@ -312,18 +323,7 @@ class LocalConf(object):
         for group, conf in groups:
             if group == "local":
                 for line in lc._section(group, conf):
-                    if line.startswith('#'):
-                        continue
-                    m = re.match(r"([^#=\s]+)\s*\=\s*(.+)", line)
-
-                    if m:
-                        self.set_local(m.group(1), m.group(2))
-                    elif re.match("(enable|disable)", line):
-                        # special case appending enable* disable*
-                        # function lines
-                        self.set_local_raw(line)
-                    else:
-                        print("SKIPPING ``%s`` from '%s'" % (line.lstrip(), lcfile))
+                    self.set_local(line)
             else:
                 for section, name, value in lc._conf(group, conf):
                     self.set(group, conf, section, name, value)
